@@ -1,14 +1,13 @@
 // Copyright 2020 ZomboDB, LLC <zombodb@gmail.com>. All rights reserved. Use of this source code is
 // governed by the MIT license that can be found in the LICENSE file.
 
-use eyre::{eyre, WrapErr};
+use eyre::eyre;
 use owo_colors::OwoColorize;
 use pgx_utils::pg_config::{PgConfig, PgConfigSelector, Pgx};
 use std::{
     process::Stdio,
     path::PathBuf,
 };
-use cargo_toml::Manifest;
 
 use crate::CommandExecute;
 
@@ -36,18 +35,7 @@ impl CommandExecute for Status {
 
         let pg_version = match self.pg_version {
             Some(s) => s,
-            None => {
-                let metadata = crate::metadata::metadata(&Default::default(), self.manifest_path.as_ref())
-                    .wrap_err("couldn't get cargo metadata")?;
-                crate::metadata::validate(&metadata)?;
-                let package_manifest_path = crate::manifest::manifest_path(&metadata, self.package.as_ref())
-                    .wrap_err("Couldn't get manifest path")?;
-                let package_manifest = Manifest::from_path(&package_manifest_path)
-                    .wrap_err("Couldn't parse manifest")?;
-                
-                crate::manifest::default_pg_version(&package_manifest)
-                    .ok_or(eyre!("no provided `pg$VERSION` flag."))?
-            }
+            None => "all".to_string(),
         };
 
         for pg_config in pgx.iter(PgConfigSelector::new(&pg_version)) {
